.. currentmodule:: sardana.macroserver.msdoor

:mod:`~sardana.macroserver.msdoor`
=======================================

.. automodule:: sardana.macroserver.msdoor

.. rubric:: Functions

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`MSDoor`

MSDoor
------------

.. inheritance-diagram:: MSDoor
    :parts: 1
    
.. autoclass:: MSDoor
    :show-inheritance:
